<?php

/**
 * @file
 * Views field handler to display a download link for a ticket PDF.
 */

class commerce_event_ticket_pdf_views_handler_field_link extends views_handler_field {

  /**
   * Get the entity type represented by this PDF.
   */
  protected function getEntityType() {
    return 'commerce_event_ticket';
  }

  /**
   * Overrides parent::option_definition().
   */
  public function option_definition() {
    $options = parent::option_definition();
    $options['text'] = array(
      'default' => t('Ticket (PDF)'),
      'translatable' => TRUE,
    );
    $options['op'] = array(
      'default' => 'view',
    );
    return $options;
  }

  /**
   * Overrides parent::options_form().
   */
  public function options_form(&$form, &$form_state) {
    $form['op'] = array(
      '#type' => 'select',
      '#title' => t('Link type'),
      '#default_value' => $this->options['op'],
      '#options' => array(
        'view' => t('View (open PDF in browser)'),
        'download' => t('Force download'),
      ),
    );
    $form['text'] = array(
      '#type' => 'textfield',
      '#title' => t('Text to display'),
      '#default_value' => $this->options['text'],
    );
    parent::options_form($form, $form_state);
  }

  /**
   * Overrides parent::render().
   */
  public function render($values) {
    $entity_id = $this->get_value($values);

    $op = !empty($this->options['op']) ? $this->options['op'] : 'view';

    $link = commerce_event_ticket_pdf_get_link($entity_id, $this->getEntityType(), $op);
    if (!$link) {
      return;
    }

    $this->options['alter']['make_link'] = TRUE;
    $this->options['alter'] = array_merge($this->options['alter'], $link);

    $text = !empty($this->options['text']) ? $this->options['text'] : t('PDF');
    return $text;
  }
}
